@@ -12,6 +12,7 @@ use Icinga\Forms\ConfirmRemovalForm;
 use Icinga\Forms\Navigation\NavigationConfigForm;
 use Icinga\Web\Controller;
 use Icinga\Web\Form;
+use Icinga\Web\Menu;
 use Icinga\Web\Navigation\Navigation;
 use Icinga\Web\Notification;
 use Icinga\Web\Url;
@@ -407,4 +408,25 @@ class NavigationController extends Controller
             $this->httpNotFound(sprintf($this->translate('Navigation item "%s" not found'), $form->getValue('name')));
         }
     }
+
+    public function dashboardAction()
+    {
+        $name = $this->params->getRequired('name');
+
+        $this->getTabs()->add('dashboard', array(
+            'active'    => true,
+            'label'     => ucwords($name),
+            'url'       => Url::fromRequest()
+        ));
+
+        $menu = new Menu();
+
+        $navigation = $menu->findItem($name);
+
+        if ($navigation === null) {
+            $this->httpNotFound($this->translate('Navigation not found'));
+        }
+
+        $this->view->navigation = $navigation;
+    }
 }
