@@ -213,19 +213,17 @@ class NavigationConfigForm extends ConfigForm
 
         $names = array();
         foreach ($this->getShareConfig($type) as $sectionName => $sectionConfig) {
-            if (
-                $sectionName !== $this->itemToLoad
+            if ($sectionName !== $this->itemToLoad
                 && $sectionConfig->owner === ($owner ?: $this->getUser()->getUsername())
-                && !in_array($sectionName, $children, true)
+                && ! in_array($sectionName, $children, true)
             ) {
                 $names[] = $sectionName;
             }
         }
 
         foreach ($this->getUserConfig($type) as $sectionName => $sectionConfig) {
-            if (
-                $sectionName !== $this->itemToLoad
-                && !in_array($sectionName, $children, true)
+            if ($sectionName !== $this->itemToLoad
+                && ! in_array($sectionName, $children, true)
             ) {
                 $names[] = $sectionName;
             }
@@ -365,8 +363,8 @@ class NavigationConfigForm extends ConfigForm
         $shared = false;
         if ($this->hasBeenShared($name)) {
             if (isset($data['parent']) && $data['parent']
-                ? !$this->hasBeenShared($data['parent'])
-                : ((! isset($data['users']) || !$data['users']) && (! isset($data['groups']) || !$data['groups']))
+                ? ! $this->hasBeenShared($data['parent'])
+                : ((! isset($data['users']) || ! $data['users']) && (! isset($data['groups']) || ! $data['groups']))
             ) {
                 // It is shared but shouldn't anymore
                 $config = $this->unshare($name, isset($data['parent']) ? $data['parent'] : null);
@@ -581,8 +579,7 @@ class NavigationConfigForm extends ConfigForm
             )
         );
 
-        if (
-            (! $itemForm->requiresParentSelection() || !isset($formData['parent']) || !$formData['parent'])
+        if ((! $itemForm->requiresParentSelection() || ! isset($formData['parent']) || ! $formData['parent'])
             && $this->getUser()->can('application/share/navigation')
         ) {
             $checked = isset($formData['shared']) ? null : (isset($formData['users']) || isset($formData['groups']));
@@ -602,7 +599,7 @@ class NavigationConfigForm extends ConfigForm
             if ($checked || (isset($formData['shared']) && $formData['shared'])) {
                 $shared = true;
                 $this->addElement(
-                    'text',
+                    'textarea',
                     'users',
                     array(
                         'label'         => $this->translate('Users'),
@@ -612,7 +609,7 @@ class NavigationConfigForm extends ConfigForm
                     )
                 );
                 $this->addElement(
-                    'text',
+                    'textarea',
                     'groups',
                     array(
                         'label'         => $this->translate('Groups'),
@@ -722,10 +719,12 @@ class NavigationConfigForm extends ConfigForm
                 if (! empty($forbiddenUsers)) {
                     $valid = false;
                     $this->getElement('users')->addError(
-                        $this->translate(sprintf(
-                            'You are not permitted to share this navigation item with the following users: %s',
+                        sprintf(
+                            $this->translate(
+                                'You are not permitted to share this navigation item with the following users: %s'
+                            ),
                             implode(', ', $forbiddenUsers)
-                        ))
+                        )
                     );
                 }
             }
@@ -744,10 +743,12 @@ class NavigationConfigForm extends ConfigForm
                 if (! empty($forbiddenGroups)) {
                     $valid = false;
                     $this->getElement('groups')->addError(
-                        $this->translate(sprintf(
-                            'You are not permitted to share this navigation item with the following groups: %s',
+                        sprintf(
+                            $this->translate(
+                                'You are not permitted to share this navigation item with the following groups: %s'
+                            ),
                             implode(', ', $forbiddenGroups)
-                        ))
+                        )
                     );
                 }
             }
@@ -781,8 +782,7 @@ class NavigationConfigForm extends ConfigForm
         if ($this->getUserConfig()->hasSection($name)) {
             return $this->getUserConfig();
         } elseif ($this->getShareConfig()->hasSection($name)) {
-            if (
-                $this->getShareConfig()->get($name, 'owner') === $this->getUser()->getUsername()
+            if ($this->getShareConfig()->get($name, 'owner') === $this->getUser()->getUsername()
                 || $this->getUser()->can('config/application/navigation')
             ) {
                 return $this->getShareConfig();
