@@ -180,7 +180,9 @@ class PreferenceForm extends Form
                         'label'         => $this->translate('Theme', 'Form element label'),
                         'multiOptions'  => $themes,
                         'value'         => $this->preferences->getValue(
-                            'icingaweb', 'theme', $defaultTheme
+                            'icingaweb',
+                            'theme',
+                            $defaultTheme
                         )
                     )
                 );
@@ -188,13 +190,21 @@ class PreferenceForm extends Form
         }
 
         $languages = array();
-        $languages['autodetect'] = sprintf($this->translate('Browser (%s)', 'preferences.form'), $this->getLocale());
+
+        $locale = $this->getLocale();
+        if ($locale !== null) {
+            $languages['autodetect'] = sprintf($this->translate('Browser (%s)', 'preferences.form'), $locale);
+        }
+
         foreach (Translator::getAvailableLocaleCodes() as $language) {
             $languages[$language] = $language;
         }
 
         $tzList = array();
-        $tzList['autodetect'] = sprintf($this->translate('Browser (%s)', 'preferences.form'), $this->getDefaultTimezone());
+        $tzList['autodetect'] = sprintf(
+            $this->translate('Browser (%s)', 'preferences.form'),
+            $this->getDefaultTimezone()
+        );
         foreach (DateTimeZone::listIdentifiers() as $tz) {
             $tzList[$tz] = $tz;
         }
@@ -223,6 +233,23 @@ class PreferenceForm extends Form
             )
         );
 
+        $this->addElement(
+            'select',
+            'show_application_state_messages',
+            array(
+                'required'      => true,
+                'label'         => $this->translate('Show application state messages'),
+                'description'   => $this->translate('Whether to show application state messages.'),
+                'multiOptions'  => [
+                    'system' => (bool) Config::app()->get('global', 'show_application_state_messages', true)
+                        ? $this->translate('System (Yes)')
+                        : $this->translate('System (No)'),
+                    1        => $this->translate('Yes'),
+                    0        => $this->translate('No')],
+                'value'         => 'system'
+            )
+        );
+
         if (Auth::getInstance()->hasPermission('application/stacktraces')) {
             $this->addElement(
                 'checkbox',
@@ -251,11 +278,23 @@ class PreferenceForm extends Form
             array(
                 'required'      => false,
                 'label'         => $this->translate('Enable auto refresh'),
-                'description'   => $this->translate('This option allows you to enable or to disable the global page content auto refresh'),
+                'description'   => $this->translate(
+                    'This option allows you to enable or to disable the global page content auto refresh'
+                ),
                 'value'         => 1
             )
         );
 
+        $this->addElement(
+            'number',
+            'default_page_size',
+            array(
+                'label'         => $this->translate('Default page size'),
+                'description'   => $this->translate('Default number of items per page for list views'),
+                'step'          => 1
+            )
+        );
+
         if ($this->store) {
             $this->addElement(
                 'submit',
@@ -320,12 +359,13 @@ class PreferenceForm extends Form
     /**
      * Return the preferred locale based on the given HTTP header and the available translations
      *
-     * @return string
+     * @return string|null
      */
     protected function getLocale()
     {
-        $locale = Translator::getPreferredLocaleCode($_SERVER['HTTP_ACCEPT_LANGUAGE']);
-        return $locale;
+        return isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])
+            ? Translator::getPreferredLocaleCode($_SERVER['HTTP_ACCEPT_LANGUAGE'])
+            : null;
     }
 
     /**
