@@ -98,6 +98,16 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
         return $query->getSelectQuery()->query();
     }
 
+    /**
+     * Get the connection configuration
+     *
+     * @return  ConfigObject
+     */
+    public function getConfig()
+    {
+        return $this->config;
+    }
+
     /**
      * Getter for database type
      *
@@ -131,7 +141,6 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
             'password'          => $this->config->password,
             'dbname'            => $this->config->dbname,
             'charset'           => $this->config->charset ?: null,
-            'persistent'        => (bool) $this->config->get('persistent', false),
             'options'           => & $genericAdapterOptions,
             'driver_options'    => & $driverOptions
         );
@@ -139,7 +148,23 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
         switch ($this->dbType) {
             case 'mssql':
                 $adapter = 'Pdo_Mssql';
-                $adapterParamaters['pdoType'] = $this->config->get('pdoType', 'dblib');
+                $pdoType = $this->config->get('pdoType');
+                if (empty($pdoType)) {
+                    if (extension_loaded('sqlsrv')) {
+                        $adapter = 'Sqlsrv';
+                    } else {
+                        $pdoType = 'dblib';
+                    }
+                }
+                if ($pdoType === 'dblib') {
+                    // Driver does not support setting attributes
+                    unset($adapterParamaters['options']);
+                    unset($adapterParamaters['driver_options']);
+                }
+                if (! empty($pdoType)) {
+                    $adapterParamaters['pdoType'] = $pdoType;
+                }
+                $defaultPort = 1433;
                 break;
             case 'mysql':
                 $adapter = 'Pdo_Mysql';
@@ -170,14 +195,13 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
                  */
                 $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] =
                     'SET SESSION SQL_MODE=\'STRICT_ALL_TABLES,NO_ZERO_IN_DATE,NO_ZERO_DATE,ERROR_FOR_DIVISION_BY_ZERO,'
-                    . 'NO_AUTO_CREATE_USER,ANSI_QUOTES,PIPES_AS_CONCAT,NO_ENGINE_SUBSTITUTION\'';
+                    . 'ANSI_QUOTES,PIPES_AS_CONCAT,NO_ENGINE_SUBSTITUTION\'';
                 if (isset($adapterParamaters['charset'])) {
                     $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] .= ', NAMES ' . $adapterParamaters['charset'];
                     unset($adapterParamaters['charset']);
                 }
                 $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] .=';';
-
-                $adapterParamaters['port'] = $this->config->get('port', 3306);
+                $defaultPort = 3306;
                 break;
             case 'oci':
                 $adapter = 'Oracle';
@@ -186,13 +210,23 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
                 $adapterParamaters['driver_options'] = array(
                     'lob_as_string' => true
                 );
+                $defaultPort = 1521;
                 break;
             case 'oracle':
                 $adapter = 'Pdo_Oci';
+                $defaultPort = 1521;
                 break;
             case 'pgsql':
                 $adapter = 'Pdo_Pgsql';
-                $adapterParamaters['port'] = $this->config->get('port', 5432);
+                $defaultPort = 5432;
+                break;
+            case 'ibm':
+                $adapter = 'Pdo_Ibm';
+                $defaultPort = 50000;
+                break;
+            case 'sqlite':
+                $adapter = 'Pdo_Sqlite';
+                $defaultPort = 0; // Dummy port because a value is required
                 break;
             default:
                 throw new ConfigurationError(
@@ -200,6 +234,7 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
                     $this->dbType
                 );
         }
+        $adapterParamaters['port'] = $this->config->get('port', $defaultPort);
         $this->dbAdapter = Zend_Db::factory($adapter, $adapterParamaters);
         $this->dbAdapter->setFetchMode(Zend_Db::FETCH_OBJ);
         // TODO(el/tg): The profiler is disabled per default, why do we disable the profiler explicitly?
@@ -319,6 +354,7 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
     /**
      * Insert a table row with the given data
      *
+     * Note that the base implementation does not perform any quoting on the $table argument.
      * Pass an array with a column name (the same as in $bind) and a PDO::PARAM_* constant as value
      * as third parameter $types to define a different type than string for a particular column.
      *
@@ -330,13 +366,19 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
      */
     public function insert($table, array $bind, array $types = array())
     {
-        $values = array();
-        foreach ($bind as $column => $_) {
-            $values[] = ':' . $column;
+        $columns = $values = array();
+        foreach ($bind as $column => $value) {
+            $columns[] = $column;
+            if ($value instanceof Zend_Db_Expr) {
+                $values[] = (string) $value;
+                unset($bind[$column]);
+            } else {
+                $values[] = ':' . $column;
+            }
         }
 
         $sql = 'INSERT INTO ' . $table
-            . ' (' . join(', ', array_keys($bind)) . ') '
+            . ' (' . join(', ', $columns) . ') '
             . 'VALUES (' . join(', ', $values) . ')';
         $statement = $this->dbAdapter->prepare($sql);
 
@@ -352,6 +394,7 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
     /**
      * Update table rows with the given data, optionally limited by using a filter
      *
+     * Note that the base implementation does not perform any quoting on the $table argument.
      * Pass an array with a column name (the same as in $bind) and a PDO::PARAM_* constant as value
      * as fourth parameter $types to define a different type than string for a particular column.
      *
@@ -365,8 +408,13 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
     public function update($table, array $bind, Filter $filter = null, array $types = array())
     {
         $set = array();
-        foreach ($bind as $column => $_) {
-            $set[] = $column . ' = :' . $column;
+        foreach ($bind as $column => $value) {
+            if ($value instanceof Zend_Db_Expr) {
+                $set[] = $column . ' = ' . $value;
+                unset($bind[$column]);
+            } else {
+                $set[] = $column . ' = :' . $column;
+            }
         }
 
         $sql = 'UPDATE ' . $table
