@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2013 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Web;
 
@@ -11,6 +11,45 @@ use Icinga\Util\Translator;
 
 /**
  * Icinga view
+ *
+ * @method Url href($path = null, $params = null) {
+ *  @param  Url|string|null $path
+ *  @param  string[]|null   $params
+ * }
+ *
+ * @method Url url($path = null, $params = null) {
+ *  @param  Url|string|null $path
+ *  @param  string[]|null   $params
+ * }
+ *
+ * @method Url qlink($title, $url, $params = null, $properties = null, $escape = true) {
+ *  @param  string          $title
+ *  @param  Url|string|null $url
+ *  @param  string[]|null   $params
+ *  @param  string[]|null   $properties
+ *  @param  bool            $escape
+ * }
+ *
+ * @method string img($url, $params = null, array $properties = array()) {
+ *  @param  Url|string|null $url
+ *  @param  string[]|null   $params
+ *  @param  string[]        $properties
+ * }
+ *
+ * @method string icon($img, $title = null, array $properties = array()) {
+ *  @param  string      $img
+ *  @param  string|null $title
+ *  @param  string[]    $properties
+ * }
+ *
+ * @method string propertiesToString($properties) {
+ *  @param  string[]    $properties
+ * }
+ *
+ * @method string attributeToString($key, $value) {
+ *  @param  string  $key
+ *  @param  string  $value
+ * }
  */
 class View extends Zend_View_Abstract
 {
@@ -19,11 +58,6 @@ class View extends Zend_View_Abstract
      */
     const CHARSET = 'UTF-8';
 
-    /**
-     * The flags we use for htmlspecialchars depend on our PHP version
-     */
-    private $replaceFlags;
-
     /**
      * Flag to register stream wrapper
      *
@@ -58,12 +92,6 @@ class View extends Zend_View_Abstract
             }
         }
 
-        if (version_compare(PHP_VERSION, '5.4.0') >= 0) {
-            $this->replaceFlags = ENT_COMPAT | ENT_SUBSTITUTE | ENT_HTML5;
-        } else {
-            $this->replaceFlags = ENT_COMPAT | ENT_IGNORE;
-        }
-
         parent::__construct($config);
     }
 
@@ -85,7 +113,7 @@ class View extends Zend_View_Abstract
      */
     public function escape($value)
     {
-        return htmlspecialchars($value, $this->replaceFlags, self::CHARSET, true);
+        return htmlspecialchars($value, ENT_COMPAT | ENT_SUBSTITUTE | ENT_HTML5, self::CHARSET, true);
     }
 
     /**
@@ -119,6 +147,33 @@ class View extends Zend_View_Abstract
         return $this;
     }
 
+    /**
+     * Set or overwrite a helper function
+     *
+     * @param   string  $name
+     * @param   Closure $function
+     *
+     * @return  $this
+     */
+    public function setHelperFunction($name, Closure $function)
+    {
+        $this->helperFunctions[$name] = $function;
+        return $this;
+    }
+
+    /**
+     * Drop a helper function
+     *
+     * @param   string  $name
+     *
+     * @return  $this
+     */
+    public function dropHelperFunction($name)
+    {
+        unset($this->helperFunctions[$name]);
+        return $this;
+    }
+
     /**
      * Call a helper function
      *
