@@ -327,6 +327,17 @@ class FilterEditor extends AbstractWidget
                     $filter = $this->applyChanges($request->getPost());
                     $url = $this->url()->setQueryString($filter->toQueryString())->addParams($preserve);
                     $url->getParams()->add('modifyFilter');
+
+                    $addFilter = $request->get('add_filter');
+                    if ($addFilter !== null) {
+                        $url->setParam('addFilter', $addFilter);
+                    }
+
+                    $removeFilter = $request->get('remove_filter');
+                    if ($removeFilter !== null) {
+                        $url->setParam('removeFilter', $removeFilter);
+                    }
+
                     $this->redirectNow($url);
                 }
             }
@@ -388,28 +399,16 @@ class FilterEditor extends AbstractWidget
 
     protected function removeLink(Filter $filter)
     {
-        return $this->view()->qlink(
-            '',
-            $this->preservedUrl()->with('removeFilter', $filter->getId()),
-            null,
-            array(
-                'icon'  => 'trash',
-                'title' => t('Remove this part of your filter')
-            )
-        );
+        return "<button type='submit' name='remove_filter' value='{$filter->getId()}'>"
+            . $this->view()->icon('trash', t('Remove this part of your filter'))
+            . '</button>';
     }
 
     protected function addLink(Filter $filter)
     {
-        return $this->view()->qlink(
-            '',
-            $this->preservedUrl()->with('addFilter', $filter->getId()),
-            null,
-            array(
-                'icon'  => 'plus',
-                'title' => t('Add another filter')
-            )
-        );
+        return "<button type='submit' name='add_filter' value='{$filter->getId()}'>"
+            . $this->view()->icon('plus', t('Add another filter'))
+            . '</button>';
     }
 
     protected function stripLink(Filter $filter)
@@ -509,7 +508,6 @@ class FilterEditor extends AbstractWidget
                  . $this->removeLink($filter)
                  . $this->addLink($filter)
                  ;
-
         }
     }
 
@@ -522,7 +520,7 @@ class FilterEditor extends AbstractWidget
         return sprintf(
             '<input type="text" name="%s" value="%s" />',
             $this->elementId('value', $filter),
-            $value
+            $this->view()->escape($value)
         );
     }
 
@@ -670,7 +668,7 @@ class FilterEditor extends AbstractWidget
             }
         }
 
-        krsort($operators, version_compare(PHP_VERSION, '5.4.0') >= 0 ? SORT_NATURAL : SORT_REGULAR);
+        krsort($operators, SORT_NATURAL);
         foreach ($operators as $id => $operator) {
             $f = $filter->getById($id);
             if ($f->getOperatorName() !== $operator) {
@@ -689,7 +687,7 @@ class FilterEditor extends AbstractWidget
                 $parent = $filter->getById($addTo);
                 $f = Filter::expression($add['column'], $add['sign'], $add['value']);
                 if (isset($add['operator'])) {
-                    switch($add['operator']) {
+                    switch ($add['operator']) {
                         case 'AND':
                             if ($parent->isExpression()) {
                                 if ($parent->isRootNode()) {
@@ -770,13 +768,17 @@ class FilterEditor extends AbstractWidget
             return '';
         }
         if (! $this->preservedUrl()->getParam('modifyFilter')) {
-            return '<div class="filter">' . $this->renderSearch() . $this->view()->escape($this->shorten($this->filter, 50)) . '</div>';
+            return '<div class="filter">'
+                . $this->renderSearch()
+                . $this->view()->escape($this->shorten($this->filter, 50))
+                . '</div>';
         }
         return  '<div class="filter">'
             . $this->renderSearch()
             . '<form action="'
             . Url::fromRequest()
             . '" class="editor" method="POST">'
+            . '<input type="submit" name="submit" value="Apply" style="display:none;"/>'
             . '<ul class="tree"><li>'
             . $this->renderFilter($this->filter)
             . '</li></ul>'
