@@ -23,11 +23,17 @@ class HostflappingstarthistoryQuery extends IdoQuery
      */
     protected $groupOrigin = array('hostgroups', 'services');
 
+    protected $subQueryTargets = array(
+        'hostgroups'    => 'hostgroup',
+        'servicegroups' => 'servicegroup'
+    );
+
     /**
      * {@inheritdoc}
      */
     protected $columnMap = array(
         'flappinghistory' => array(
+            'id'            => 'hfh.flappinghistory_id',
             'host_name'     => 'ho.name1',
             'object_id'     => 'hfh.object_id',
             'object_type'   => '(\'host\')',
@@ -169,4 +175,19 @@ class HostflappingstarthistoryQuery extends IdoQuery
             array()
         );
     }
+
+    protected function joinSubQuery(IdoQuery $query, $name, $filter, $and, $negate, &$additionalFilter)
+    {
+        if ($name === 'hostgroup') {
+            $query->joinVirtualTable('members');
+
+            return ['hgm.host_object_id', 'ho.object_id'];
+        } elseif ($name === 'servicegroup') {
+            $query->joinVirtualTable('services');
+
+            return ['s.host_object_id', 'ho.object_id'];
+        }
+
+        return parent::joinSubQuery($query, $name, $filter, $and, $negate, $additionalFilter);
+    }
 }
