@@ -13,6 +13,11 @@ class ServicenotificationQuery extends IdoQuery
      */
     protected $allowCustomVars = true;
 
+    protected $subQueryTargets = array(
+        'hostgroups'    => 'hostgroup',
+        'servicegroups' => 'servicegroup'
+    );
+
     /**
      * {@inheritdoc}
      */
@@ -21,6 +26,7 @@ class ServicenotificationQuery extends IdoQuery
             'notification_contact_name' => 'co.name1'
         ),
         'history' => array(
+            'id'        => 'sn.notification_id',
             'output'    => null,
             'state'     => 'sn.state',
             'timestamp' => 'UNIX_TIMESTAMP(sn.start_time)',
@@ -38,6 +44,7 @@ class ServicenotificationQuery extends IdoQuery
         'notifications' => array(
             'host_name'                 => 'so.name1',
             'notification_output'       => 'sn.output',
+            'notification_reason'       => 'sn.notification_reason',
             'notification_state'        => 'sn.state',
             'notification_timestamp'    => 'UNIX_TIMESTAMP(sn.start_time)',
             'object_type'               => '(\'service\')',
@@ -203,8 +210,7 @@ class ServicenotificationQuery extends IdoQuery
     {
         $group = array();
 
-        if (
-            $this->hasJoinedVirtualTable('history')
+        if ($this->hasJoinedVirtualTable('history')
             || $this->hasJoinedVirtualTable('hostgroups')
             || $this->hasJoinedVirtualTable('servicegroups')
         ) {
@@ -232,4 +238,21 @@ class ServicenotificationQuery extends IdoQuery
 
         return $group;
     }
+
+    protected function joinSubQuery(IdoQuery $query, $name, $filter, $and, $negate, &$additionalFilter)
+    {
+        if ($name === 'hostgroup') {
+            $this->requireVirtualTable('services');
+
+            $query->joinVirtualTable('members');
+
+            return ['hgm.host_object_id', 's.host_object_id'];
+        } elseif ($name === 'servicegroup') {
+            $query->joinVirtualTable('members');
+
+            return ['sgm.service_object_id', 'so.object_id'];
+        }
+
+        return parent::joinSubQuery($query, $name, $filter, $and, $negate, $additionalFilter);
+    }
 }
