@@ -23,6 +23,11 @@ class ServicestatusQuery extends IdoQuery
      */
     protected $groupOrigin = array('hostgroups', 'servicegroups');
 
+    protected $subQueryTargets = array(
+        'hostgroups'    => 'hostgroup',
+        'servicegroups' => 'servicegroup'
+    );
+
     /**
      * {@inheritdoc}
      */
@@ -101,37 +106,28 @@ class ServicestatusQuery extends IdoQuery
             'host_process_performance_data'         => 'hs.process_performance_data',
             'host_retry_check_interval'             => 'hs.retry_check_interval',
             'host_scheduled_downtime_depth'         => 'hs.scheduled_downtime_depth',
-            'host_severity'                         => 'CASE WHEN hs.current_state = 0
-            THEN
-                CASE WHEN hs.has_been_checked = 0 OR hs.has_been_checked IS NULL
-                     THEN 16
-                     ELSE 0
-                END
-                +
-                CASE WHEN hs.problem_has_been_acknowledged = 1
-                     THEN 2
-                     ELSE
-                        CASE WHEN hs.scheduled_downtime_depth > 0
-                            THEN 1
-                            ELSE 4
+            'host_severity'                         => '
+                CASE
+                    WHEN hs.has_been_checked = 0 OR hs.has_been_checked IS NULL
+                    THEN 16
+                ELSE
+                    CASE
+                        WHEN hs.current_state = 0
+                        THEN 1
+                    ELSE
+                        CASE
+                            WHEN hs.current_state = 1 THEN 64
+                            WHEN hs.current_state = 2 THEN 32
+                            ELSE 256
                         END
-                END
-            ELSE
-                CASE WHEN hs.has_been_checked = 0 OR hs.has_been_checked IS NULL THEN 16
-                     WHEN hs.current_state = 1 THEN 32
-                     WHEN hs.current_state = 2 THEN 64
-                     ELSE 256
-                END
-                +
-                CASE WHEN hs.problem_has_been_acknowledged = 1
-                     THEN 2
-                     ELSE
-                        CASE WHEN hs.scheduled_downtime_depth > 0
-                            THEN 1
-                            ELSE 4
+                        +
+                        CASE
+                            WHEN hs.problem_has_been_acknowledged = 1 THEN 2
+                            WHEN hs.scheduled_downtime_depth > 0 THEN 1
+                            ELSE 256
                         END
-                END
-            END',
+                    END
+                END',
             'host_state'                            => 'CASE WHEN hs.has_been_checked = 0 OR hs.has_been_checked IS NULL THEN 99 ELSE hs.current_state END',
             'host_state_type'                       => 'hs.state_type',
             'host_status_update_time'               => 'hs.status_update_time',
@@ -147,6 +143,7 @@ class ServicestatusQuery extends IdoQuery
             'object_type'               => '(\'service\')',
             'service'                   => 'so.name2 COLLATE latin1_general_ci',
             'service_action_url'        => 's.action_url',
+            'service_check_interval'    => '(s.check_interval * 60)',
             'service_description'       => 'so.name2',
             'service_display_name'      => 's.display_name COLLATE latin1_general_ci',
             'service_host'              => 'so.name1 COLLATE latin1_general_ci',
@@ -192,6 +189,7 @@ class ServicestatusQuery extends IdoQuery
             'service_last_hard_state_change'            => 'UNIX_TIMESTAMP(ss.last_hard_state_change)',
             'service_last_notification'                 => 'UNIX_TIMESTAMP(ss.last_notification)',
             'service_last_state_change'                 => 'UNIX_TIMESTAMP(ss.last_state_change)',
+            'service_last_state_change_ts'              => 'ss.last_state_change',
             'service_last_time_critical'                => 'ss.last_time_critical',
             'service_last_time_ok'                      => 'ss.last_time_ok',
             'service_last_time_unknown'                 => 'ss.last_time_unknown',
@@ -270,7 +268,8 @@ class ServicestatusQuery extends IdoQuery
             'service_state'                             => 'CASE WHEN ss.has_been_checked = 0 OR ss.has_been_checked IS NULL THEN 99 ELSE ss.current_state END',
             'service_state_type'                        => 'ss.state_type',
             'service_status_update_time'                => 'ss.status_update_time',
-            'service_unhandled'                         => 'CASE WHEN (ss.problem_has_been_acknowledged + ss.scheduled_downtime_depth + COALESCE(hs.current_state, 0)) = 0 THEN 1 ELSE 0 END'
+            'service_unhandled'                         => 'CASE WHEN (ss.problem_has_been_acknowledged + ss.scheduled_downtime_depth + COALESCE(hs.current_state, 0)) = 0 THEN 1 ELSE 0 END',
+            'problems'                                  => 'CASE WHEN COALESCE(ss.current_state, 0) = 0 THEN 0 ELSE 1 END'
         )
     );
 
@@ -419,4 +418,19 @@ class ServicestatusQuery extends IdoQuery
             parent::registerGroupColumns($alias, $table, $groupedColumns, $groupedTables);
         }
     }
+
+    protected function joinSubQuery(IdoQuery $query, $name, $filter, $and, $negate, &$additionalFilter)
+    {
+        if ($name === 'hostgroup') {
+            $query->joinVirtualTable('members');
+
+            return ['hgm.host_object_id', 's.host_object_id'];
+        } elseif ($name === 'servicegroup') {
+            $query->joinVirtualTable('members');
+
+            return ['sgm.service_object_id', 'so.object_id'];
+        }
+
+        return parent::joinSubQuery($query, $name, $filter, $and, $negate, $additionalFilter);
+    }
 }
