@@ -3,6 +3,7 @@
 
 namespace Icinga\Module\Monitoring\Web\Controller;
 
+use Exception;
 use Icinga\Module\Monitoring\Controller;
 use Icinga\Module\Monitoring\Forms\Command\Object\CheckNowCommandForm;
 use Icinga\Module\Monitoring\Forms\Command\Object\DeleteCommentCommandForm;
@@ -10,6 +11,7 @@ use Icinga\Module\Monitoring\Forms\Command\Object\DeleteDowntimeCommandForm;
 use Icinga\Module\Monitoring\Forms\Command\Object\ObjectsCommandForm;
 use Icinga\Module\Monitoring\Forms\Command\Object\RemoveAcknowledgementCommandForm;
 use Icinga\Module\Monitoring\Forms\Command\Object\ToggleObjectFeaturesCommandForm;
+use Icinga\Module\Monitoring\Hook\DetailviewExtensionHook;
 use Icinga\Web\Hook;
 use Icinga\Web\Url;
 use Icinga\Web\Widget\Tabextension\DashboardAction;
@@ -45,7 +47,7 @@ abstract class MonitoredObjectController extends Controller
             $this->view->tickets = Hook::first('ticket');
         }
         if (Hook::has('grapher')) {
-            $this->view->grapher = Hook::first('grapher');
+            $this->view->graphers = Hook::all('grapher');
         }
     }
 
@@ -55,25 +57,8 @@ abstract class MonitoredObjectController extends Controller
     public function showAction()
     {
         $this->setAutorefreshInterval(10);
+        $this->setupQuickActionForms();
         $auth = $this->Auth();
-        if ($auth->hasPermission('monitoring/command/schedule-check')) {
-            $checkNowForm = new CheckNowCommandForm();
-            $checkNowForm
-                ->setObjects($this->object)
-                ->handleRequest();
-            $this->view->checkNowForm = $checkNowForm;
-        }
-        if (! in_array((int) $this->object->state, array(0, 99))) {
-            if ((bool) $this->object->acknowledged) {
-                if ($auth->hasPermission('monitoring/command/remove-acknowledgement')) {
-                    $removeAckForm = new RemoveAcknowledgementCommandForm();
-                    $removeAckForm
-                        ->setObjects($this->object)
-                        ->handleRequest();
-                    $this->view->removeAckForm = $removeAckForm;
-                }
-            }
-        }
         $this->object->populate();
         $this->handleFormatRequest();
         $toggleFeaturesForm = new ToggleObjectFeaturesCommandForm(array(
@@ -96,6 +81,22 @@ abstract class MonitoredObjectController extends Controller
         }
         $this->view->showInstance = $this->backend->select()->from('instance')->count() > 1;
         $this->view->object = $this->object;
+
+        $this->view->extensionsHtml = array();
+        foreach (Hook::all('Monitoring\DetailviewExtension') as $hook) {
+            /** @var DetailviewExtensionHook $hook */
+
+            try {
+                $html = $hook->setView($this->view)->getHtmlForObject($this->object);
+            } catch (Exception $e) {
+                $html = $this->view->escape($e->getMessage());
+            }
+
+            $this->view->extensionsHtml[] =
+                '<div class="icinga-module module-' . $this->view->escape($hook->getModule()->getName()) . '">'
+                . $html
+                . '</div>';
+        }
     }
 
     /**
@@ -132,6 +133,7 @@ abstract class MonitoredObjectController extends Controller
         $this->view->tabs->remove('dashboard');
         $this->view->tabs->remove('menu-entry');
         $this->_helper->viewRenderer('partials/command/object-command-form', null, true);
+        $this->setupQuickActionForms();
         return $form;
     }
 
@@ -151,7 +153,10 @@ abstract class MonitoredObjectController extends Controller
             );
             $groupName = $this->object->getType() . 'groups';
             $payload[$groupName] = $this->object->$groupName;
-            $this->getResponse()->json()->setSuccessData($payload)->sendResponse();
+            $this->getResponse()->json()
+                ->setSuccessData($payload)
+                ->setAutoSanitize()
+                ->sendResponse();
         }
     }
 
@@ -256,4 +261,27 @@ abstract class MonitoredObjectController extends Controller
         }
         $tabs->extend(new DashboardAction())->extend(new MenuAction());
     }
+
+    /**
+     * Create quick action forms and pass them to the view
+     */
+    protected function setupQuickActionForms()
+    {
+        $auth = $this->Auth();
+        if ($auth->hasPermission('monitoring/command/schedule-check')) {
+            $this->view->checkNowForm = $checkNowForm = new CheckNowCommandForm();
+            $checkNowForm
+                ->setObjects($this->object)
+                ->handleRequest();
+        }
+        if (! in_array((int) $this->object->state, array(0, 99))
+            && $this->object->acknowledged
+            && $auth->hasPermission('monitoring/command/remove-acknowledgement')
+        ) {
+            $this->view->removeAckForm = $removeAckForm = new RemoveAcknowledgementCommandForm();
+            $removeAckForm
+                ->setObjects($this->object)
+                ->handleRequest();
+        }
+    }
 }
