@@ -4,6 +4,7 @@
 namespace Icinga\Module\Monitoring\Web\Navigation\Renderer;
 
 use Exception;
+use Icinga\Application\Logger;
 use Icinga\Module\Monitoring\Backend\MonitoringBackend;
 use Icinga\Web\Navigation\Renderer\BadgeNavigationItemRenderer;
 
@@ -30,6 +31,14 @@ class BackendAvailabilityNavigationItemRenderer extends BadgeNavigationItemRende
                 array('is_currently_running', 'notifications_enabled')
             )
             ->fetchRow();
+
+        if ($programStatus === false) {
+            throw new Exception(sprintf(
+                mt('monitoring', '%s is currently not up and running'),
+                MonitoringBackend::instance()->getName()
+            ));
+        }
+
         return $programStatus;
     }
 
@@ -40,37 +49,33 @@ class BackendAvailabilityNavigationItemRenderer extends BadgeNavigationItemRende
     {
         if ($this->count === null) {
             try {
-                $count = 0;
                 $programStatus = $this->isCurrentlyRunning();
-                $titles = array();
-                if (! (bool) $programStatus->notifications_enabled) {
-                    $count = 1;
-                    $this->state = static::STATE_WARNING;
-                    $titles[] = mt('monitoring', 'Notifications are disabled');
-                }
-                if (! (bool) $programStatus->is_currently_running) {
-                    $count = 1;
-                    $this->state = static::STATE_CRITICAL;
-                    array_unshift($titles, sprintf(
-                        mt('monitoring', 'Monitoring backend %s is not running'),
-                        MonitoringBackend::instance()->getName()
-                    ));
-                }
-                $this->count = $count;
-                $this->title = implode('. ', $titles);
-            } catch (Exception $_) {
+            } catch (Exception $e) {
+                Logger::debug($e);
                 $this->count = 1;
+                $this->state = static::STATE_UNKNOWN;
+                $this->title = $e->getMessage();
+                return $this->count;
             }
+            $count = 0;
+            $titles = array();
+            if (! (bool) $programStatus->notifications_enabled) {
+                $count = 1;
+                $this->state = static::STATE_WARNING;
+                $titles[] = mt('monitoring', 'Notifications are disabled');
+            }
+            if (! (bool) $programStatus->is_currently_running) {
+                $count = 1;
+                $this->state = static::STATE_CRITICAL;
+                array_unshift($titles, sprintf(
+                    mt('monitoring', 'Monitoring backend %s is not running'),
+                    MonitoringBackend::instance()->getName()
+                ));
+            }
+            $this->count = $count;
+            $this->title = implode('. ', $titles);
         }
 
         return $this->count;
     }
-
-    /**
-     * {@inheritdoc}
-     */
-    public function getState()
-    {
-        return $this->state;
-    }
 }
