@@ -10,18 +10,28 @@ use Icinga\Module\Setup\Webserver;
  */
 class Apache extends Webserver
 {
-    /**
-     * @return array
-     */
+    protected $fpmUri = 'fcgi://127.0.0.1:9000';
+
     protected function getTemplate()
     {
             return  <<<'EOD'
 Alias {urlPath} "{documentRoot}"
 
+# Remove comments if you want to use PHP FPM and your Apache version is older than 2.4
+#<IfVersion < 2.4>
+#    # Forward PHP requests to FPM
+#    SetEnvIf Authorization "(.*)" HTTP_AUTHORIZATION=$1
+#    <LocationMatch "^{urlPath}/(.*\.php)$">
+#        ProxyPassMatch "fcgi://127.0.0.1:9000/{documentRoot}/$1"
+#    </LocationMatch>
+#</IfVersion>
+
 <Directory "{documentRoot}">
     Options SymLinksIfOwnerMatch
     AllowOverride None
 
+    DirectoryIndex index.php
+
     <IfModule mod_authz_core.c>
         # Apache 2.4
         <RequireAll>
@@ -51,10 +61,20 @@ Alias {urlPath} "{documentRoot}"
 
     <IfModule !mod_rewrite.c>
         DirectoryIndex error_norewrite.html
-        ErrorDocument 404 /error_norewrite.html
+        ErrorDocument 404 {urlPath}/error_norewrite.html
     </IfModule>
+
+# Remove comments if you want to use PHP FPM and your Apache version
+# is greater than or equal to 2.4
+#    <IfVersion >= 2.4>
+#        # Forward PHP requests to FPM
+#        SetEnvIf Authorization "(.*)" HTTP_AUTHORIZATION=$1
+#        <FilesMatch "\.php$">
+#            SetHandler "proxy:{fpmUri}"
+#            ErrorDocument 503 {urlPath}/error_unavailable.html
+#        </FilesMatch>
+#    </IfVersion>
 </Directory>
 EOD;
-
     }
 }
