@@ -30,7 +30,15 @@
 
         this.iconCache = {};
 
+        /**
+         * Whether auto-refresh is enabled
+         */
         this.autorefreshEnabled = true;
+
+        /**
+         * Whether auto-refresh is suspended due to visibility of page
+         */
+        this.autorefreshSuspended = false;
     };
 
     Icinga.Loader.prototype = {
@@ -209,13 +217,17 @@
 
         autorefresh: function () {
             var _this = this;
-            if (_this.autorefreshEnabled !== true) {
-                return;
-            }
 
             $('.container').filter(this.filterAutorefreshingContainers).each(function (idx, el) {
                 var $el = $(el);
                 var id = $el.attr('id');
+
+                // Always request application-state
+                if (id !== 'application-state' && (! _this.autorefreshEnabled || _this.autorefreshSuspended)) {
+                    // Continue
+                    return true;
+                }
+
                 if (typeof _this.requests[id] !== 'undefined') {
                     _this.icinga.logger.debug('No refresh, request pending for ', id);
                     return;
@@ -331,6 +343,12 @@
                 }
             }
 
+            var useHttp = req.getResponseHeader('X-Icinga-Redirect-Http');
+            if (useHttp === 'yes') {
+                window.location.replace(redirect);
+                return true;
+            }
+
             this.redirectToUrl(
                 redirect, req.$target, req.url, req.getResponseHeader('X-Icinga-Rerender-Layout'), req.forceFocus,
                 req.getResponseHeader('X-Icinga-Refresh')
@@ -570,7 +588,7 @@
                 oldNotifications.appendTo($('#notifications'));
             }
             if (url.match(/#/)) {
-                this.icinga.ui.focusElement(url.split(/#/)[1], req.$target);
+                setTimeout(this.icinga.ui.focusElement, 0, url.split(/#/)[1], req.$target);
             }
             if (newBody) {
                 this.icinga.ui.fixDebugVisibility().triggerWindowResize();
@@ -845,15 +863,6 @@
 
                     if ($activeElement.length && $activeElement.is(':visible')) {
                         $activeElement.focus();
-                        if ($activeElement.is('input[type=text]')) {
-                            if (typeof $activeElement[0].setSelectionRange === 'function') {
-                                // Place focus after the last character. Could be extended to other
-                                // input types, would require some \r\n "magic" to work around issues
-                                // with some browsers
-                                var len = $activeElement.val().length;
-                                $activeElement[0].setSelectionRange(len, len);
-                            }
-                        }
                     } else if (! autorefresh) {
                         if (focusFallback) {
                             $(focusFallback.parent).find(focusFallback.child).focus();
@@ -866,7 +875,7 @@
             }
 
             if (scrollPos !== false) {
-                $container.scrollTop(scrollPos);
+                setTimeout($container.scrollTop.bind($container), 0, scrollPos);
             }
             var icinga = this.icinga;
             //icinga.events.applyHandlers($container);
